/*
 * (c) Copyright Adrian Pop, adrpo@ida.liu.se, 2006-02-21
 * All Rights Reserved.
 */
package org.pelab.rml.editor.doc;


import java.util.ArrayList;
import java.util.List;
import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.rules.EndOfLineRule;
import org.eclipse.jface.text.rules.IRule;
import org.eclipse.jface.text.rules.IToken;
import org.eclipse.jface.text.rules.RuleBasedScanner;
import org.eclipse.jface.text.rules.SingleLineRule;
import org.eclipse.jface.text.rules.Token;
import org.eclipse.jface.text.rules.WhitespaceRule;
import org.eclipse.jface.text.rules.WordRule;
import org.eclipse.swt.SWT;

import org.pelab.rml.editor.rml.IRMLLanguageWords;
import org.pelab.rml.editor.utils.RMLColorManager;
import org.pelab.rml.editor.utils.RMLWhitespaceDetector;
import org.pelab.rml.editor.utils.RMLWordDetector;

/**
 * A C Sharp code scanner.
 */
public class RMLCodeScanner 
				extends RuleBasedScanner 
				implements IRMLLanguageWords {


	private TextAttribute fComment;
	private TextAttribute fKeyword;
	private TextAttribute fType;
	private TextAttribute fString;
	private RMLColorManager fColorProvider;

	/**
	 * Creates a C Sharp code scanner
	 */
	public RMLCodeScanner(RMLColorManager provider) {

		IToken keyword= new Token(new TextAttribute(provider.getColor(RMLColorManager.KEYWORD), provider.getColor(RMLColorManager.BACKGROUND), SWT.BOLD));
		IToken type= new Token(new TextAttribute(provider.getColor(RMLColorManager.TYPE), provider.getColor(RMLColorManager.BACKGROUND), SWT.BOLD));
		IToken string= new Token(new TextAttribute(provider.getColor(RMLColorManager.STRING)));
		IToken comment= new Token(new TextAttribute(provider.getColor(RMLColorManager.SINGLE_LINE_COMMENT)));
		IToken other= new Token(new TextAttribute(provider.getColor(RMLColorManager.DEFAULT)));

		setDefaultReturnToken(other);
		
		List rules= new ArrayList();

		// Add rule for single line comments.
		rules.add(new EndOfLineRule("//", comment)); 

		// Add rule for strings and character constants.
		rules.add(new SingleLineRule("\"", "\"", string, '\\')); 
		rules.add(new SingleLineRule("'", "'", string, '\\')); 

		// Add generic whitespace rule.
		rules.add(new WhitespaceRule(new RMLWhitespaceDetector()));

		// Add word rule for keywords, types, and constants.
		WordRule wordRule= new WordRule(new RMLWordDetector(), other);
		for (int i= 0; i < keywords.length; i++)
			wordRule.addWord(keywords[i], keyword);
		for (int i= 0; i < types.length; i++)
			wordRule.addWord(types[i], type);
		for (int i= 0; i < constants.length; i++)
			wordRule.addWord(constants[i], type);
		rules.add(wordRule);

		IRule[] result= new IRule[rules.size()];
		rules.toArray(result);
		setRules(result);
	}
}
