/*
 * (c) Copyright Adrian Pop, adrpo@ida.liu.se, 2006-02-21
 * All Rights Reserved.
 */
package org.pelab.rml.editor.doc;

import java.util.*;
import org.eclipse.jface.text.TextAttribute;
import org.eclipse.jface.text.rules.*;
import org.eclipse.swt.SWT;

import org.pelab.rml.editor.rml.IRMLLanguageWords;
import org.pelab.rml.editor.utils.*;

/**
 * A rule based C Sharp Doc scanner.
 */
public class RMLDocScanner
	extends RuleBasedScanner
	implements IRMLLanguageWords {

	/**
	 * A key word detector.
	 */
	static class RMLDocKeyWordDetector implements IWordDetector {
		public boolean isWordStart(char c) {
			return c=='<';
		}

		public boolean isWordPart(char c) {
			return Character.isLetter(c) || c=='/' || c=='>';
		}
	};


	/**
	 * Create a new c sharp doc scanner.
	 */
	public RMLDocScanner(RMLColorManager provider) {
		super();
		
		IToken defaultToken =
			new Token(new TextAttribute(provider.getColor(RMLColorManager.RML_DOC_DEFAULT)));
		IToken keyword =
			new Token(new TextAttribute(provider.getColor(RMLColorManager.RML_DOC_KEYWORD), provider.getColor(RMLColorManager.BACKGROUND), SWT.BOLD));
		IToken tag =
			new Token(new TextAttribute(provider.getColor(RMLColorManager.RML_DOC_TAG)));

		setDefaultReturnToken(defaultToken);

		List list = new ArrayList();

		// Add generic whitespace rule.
		list.add(new WhitespaceRule(new RMLWhitespaceDetector()));

		// Add word rule for keywords.
		WordRule tagRule = new WordRule(new RMLDocKeyWordDetector(), tag);
		for (int i = 0; i < RMLDocWords.length; i++) {
			tagRule.addWord("<" + RMLDocWords[i] + ">", keyword); 
			tagRule.addWord("</" + RMLDocWords[i] + ">", keyword);
		}
		list.add(tagRule);


		IRule[] result = new IRule[list.size()];
		list.toArray(result);
		setRules(result);
	}
}