/*
 * This file is part of RML Development Tooling.
 *
 * Copyright (c) 2006, Adrian Pop, adrpo@ida.liu.se
 *
 * Created on February 19, 2006
 *
 */
package org.pelab.rml.editor.parser;

import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IMarker;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.texteditor.MarkerUtilities;
import org.pelab.rml.RMLPlugin;
import org.pelab.rml.preferences.RMLPreferencePage;
import org.pelab.rml.views.RMLConsoleView;

/**
 * @author adrpo
 *  
 */
public abstract class AbstractCompilerMessageParser implements CompilerMessageParser {

    protected static final String ERROR = "Error"; 
    protected static final String WARNING = "Warning"; 
    int offset = 0;

    public void parseCompilerMessage(IFile in_file, String in_compilerOutPut)
            throws CoreException 
   {
        if (in_compilerOutPut == null) return;    	
		/* clear the console */
		offset = 0;
		String current = null;
		int i = 0; int j = 0;		
		while (true)
		{
			i = 0; j = 0;
			while (in_compilerOutPut.charAt(i) == '\n') 
			{
				i++;
				if (i == in_compilerOutPut.length()) return;
			}
			offset += i;
			in_compilerOutPut = in_compilerOutPut.substring(i);
			if (in_compilerOutPut == "") return;
			j = in_compilerOutPut.indexOf("\n");
			if (j == -1) /* we did not find it, use the end.*/
			{
				current = in_compilerOutPut;
			}
			else
			{
				current = in_compilerOutPut.substring(0, j);
			}
			parseLine(in_file, current, offset);
			in_compilerOutPut = in_compilerOutPut.substring(j);
			offset += current.length();   
		}
    }
    
	/**
	 * Prints out the string represented by the string buffer
	 */
	protected void appendResultInConsole(String output) 
	{
		RMLConsoleView console = RMLPlugin.getRMLConsole();
		if (console != null) console.appendOutputText(output);
	}
        
    /**
     * @param in_file
     * @param lc_fileName
     * @param current
     * @throws CoreException
     */
    protected abstract void parseLine(IFile in_file, String in_ligne, int offset) throws CoreException;

    /**
     * @param in_file
     * @param message
     * @param lineNumber
     * @throws CoreException
     */
    protected void setMarker(IFile in_file, String message, int lineNumber) throws CoreException {
        Map attributes = new HashMap();
        message = message.trim();
        if (message.startsWith(ERROR))
            attributes.put(IMarker.SEVERITY, new Integer(IMarker.SEVERITY_ERROR));
        else if (message.startsWith(WARNING))
            attributes.put(IMarker.SEVERITY, new Integer(IMarker.SEVERITY_WARNING));
        else
            attributes.put(IMarker.SEVERITY, new Integer(IMarker.SEVERITY_INFO));
    
        //System.out.println("Creating marker: "+in_file.getName()+":"+lineNumber+" "+message);
        MarkerUtilities.setLineNumber(attributes, lineNumber);
        MarkerUtilities.setMessage(attributes, message);
        MarkerUtilities.createMarker(in_file, attributes, IMarker.PROBLEM);
    }
}