/*
 * This file is part of RML Development Tooling.
 *
 * Copyright (c) 2006, Adrian Pop, adrpo@ida.liu.se
 *
 * Created on February 19, 2006
 *
 */
package org.pelab.rml.editor.parser;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;
import org.pelab.rml.views.RMLConsoleView;
import org.eclipse.debug.ui.console.FileLink;
import org.pelab.rml.RMLPlugin;


import java.util.regex.*;

/**
 * @author adrpo
 *
 */
public class RMLCompilerMessageParser extends AbstractCompilerMessageParser implements CompilerMessageParser {

    private static String regexpRML;
    private static String regexpGeneral;    
    private static Pattern pattern;
    private static Matcher matcher;

    /**
     * @param in_file
     * @param lc_fileName
     * @param current
     * @throws CoreException
     */
    protected void parseLine(IFile in_file, String in_ligne, int offset) throws CoreException 
    {
    	if (in_ligne == null) return;     	
    	String strFileName = null;
    	String strLine = null;
    	String strMsg = null;
    	try
    	{
    	regexpRML = "(.*)\\:([0-9]*)\\.[0-9]*\\-[0-9]*\\.[0-9]*(.*)";
    	regexpGeneral = "(.*)\\:([0-9]*)(.*)";    	
    	pattern = Pattern.compile(regexpRML);
        matcher = pattern.matcher(in_ligne);
        in_ligne += "\n";
    	//System.out.println("Matches:" + matcher.groupCount());        
        if (!matcher.matches()) 
        {
        	/* if the RML pattern does not match try the general pattern! */
        	pattern = Pattern.compile(regexpGeneral);
        	matcher = pattern.matcher(in_ligne);
            if (!matcher.matches()) 
            {        	
            	//appendResultInConsole(in_ligne);        	
            	/* if did not match append the lines in the console */
            	return;
            }
        }
        if (matcher.groupCount() != 3) return;
        strFileName = matcher.group(1);
        strLine = matcher.group(2);
        strMsg = matcher.group(3);
        //System.out.println("Matches:[" + strFileName + ":" + strLine + " " + strMsg + "]" );
        //found = true;
        //if(!found) System.out.println("No match found.");
    	}
    	catch (Exception e)
    	{
    		//e.printStackTrace();
    	}
    	try
    	{
    		/* ok, see if the strFileName is the same as the open one */
        	int lineNumber = Integer.parseInt(strLine);
        	IFile iFile = null;
        	FileLink fileLink = null;
        	RMLConsoleView console = RMLPlugin.getRMLConsole();
        	IResource iResource = null;
    		if (in_file.getName().equals(strFileName))
    		{
	        	iFile = in_file;
	        	fileLink = new FileLink(iFile, "org.pelab.rml.editor.RMLEditor",-1,-1,lineNumber);    		    			
    		}
    		else
    		{
    			/* see if we can find the file in the project */
	        	iResource = in_file.getProject().findMember(strFileName);
    			/* see if we can find the file in the workspace */
	        	if (iResource == null) iResource = in_file.getWorkspace().getRoot().findMember(strFileName);
    			/* see if we can find the file in the path */	        		
	        	if (iResource == null) iResource = in_file.getParent().findMember(strFileName);
	        	if (iResource != null)
	        	{	        		
		        	iFile = (IFile) iResource;
		        	fileLink = new FileLink(iFile, "org.pelab.rml.editor.RMLEditor",-1,-1,lineNumber);    		
	        	}
    		}
            setMarker(iFile, strMsg, lineNumber);        	
    		console.getConsole().addHyperlink(
    					fileLink, 
    					offset, 
    					strFileName.length() + 1 + strLine.length());        	
    	}
    	catch(Exception e)
    	{
    		e.printStackTrace();
    	}
    }
    
}
