/*
 * This file is part of RML Development Tooling.
 *
 * Copyright (c) 2006, Adrian Pop, adrpo@ida.liu.se
 */

package org.pelab.rml.preferences;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.jface.preference.FileFieldEditor;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.jface.preference.RadioGroupFieldEditor;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import org.pelab.rml.RMLPlugin;

/**
 * This class represents a preference page that
 * is contributed to the Preferences dialog. By 
 * subclassing <samp>FieldEditorPreferencePage</samp>, we
 * can use the field support built into JFace that allows
 * us to create a page that is small and knows how to 
 * save, restore and apply itself.
 * <p>
 * This page is used to modify preferences only. They
 * are stored in the preference store that belongs to
 * the main plug-in class. That way, preferences can
 * be accessed directly via the preference store.
 */


public class RMLPreferencePage
	extends FieldEditorPreferencePage
	implements IWorkbenchPreferencePage {
	
	public static final String RML_COMPILER_TYPE = "rml.compiler.type";
	public static final String RML_COMPILER_PATH = "rml.compiler.path";
	public static final String AUTO_COMPILE = "rml.autoBuild";
	public static final String SHOW_OUTPUT_IN_CONSOLE = "rml.showOutputInConsole";
	
	public static final String RML = "rml";


	public RMLPreferencePage() {
		super(GRID);
		setPreferenceStore(RMLPlugin.getDefault().getPreferenceStore());
		setDescription("RML preference page");
		initializeDefaults();
	}
/**
 * Sets the default values of the preferences.
 */
	private void initializeDefaults() {
		IPreferenceStore store = getPreferenceStore();
		store.setDefault(RML_COMPILER_PATH, "");
		store.setDefault(AUTO_COMPILE, true);
		store.setDefault(SHOW_OUTPUT_IN_CONSOLE, true);
	}
	
/**
 * Creates the field editors. Field editors are abstractions of
 * the common GUI blocks needed to manipulate various types
 * of preferences. Each field editor knows how to save and
 * restore itself.
 */

	public void createFieldEditors() {
		
		addField(new RadioGroupFieldEditor(	RML_COMPILER_TYPE,
				RMLPlugin.getResourceString("preferences.choixCompilerType"),1,
				new String[][] { { RMLPlugin.getResourceString("preferences.rml"), RML }
								 }, getFieldEditorParent()));
		addField(new FileFieldEditor(RML_COMPILER_PATH, RMLPlugin.getResourceString("preferences.setCompilerPath"), getFieldEditorParent()));
		addField(new BooleanFieldEditor(AUTO_COMPILE, RMLPlugin.getResourceString("preferences.autoCompile"), getFieldEditorParent()));
		addField(new BooleanFieldEditor(SHOW_OUTPUT_IN_CONSOLE, RMLPlugin.getResourceString("preferences.showOutputInConsole"), getFieldEditorParent()));
		
		

		
	}
	
	public void init(IWorkbench workbench) {
	}
}