/*
 * This file is part of RML Development Tooling.
 *
 * Copyright (c) 2006, Adrian Pop, adrpo@ida.liu.se
 * 
 * created Februrary 19, 2006
 */

package org.pelab.rml.views;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.text.IDocument;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.console.*;
import org.eclipse.ui.part.*;
import org.eclipse.jface.text.rules.DefaultPartitioner;

/**
 * The RMLConsole is used to display the RML compiler's output
 * @see ViewPart
 */
public class RMLConsoleView extends ViewPart {

	private TextConsoleViewer viewer = null;
	private RMLTextConsole console = null; 
	public static final String CONSOLE_ID = "org.pelab.rml.views.RMLConsoleView";

	/**
	 * The constructor.
	 */
	public RMLConsoleView() 
	{		
		console = new RMLTextConsole();
	}
	
	public IDocument getDocument() { return console.getDocument(); } 
	public RMLTextConsole getConsole() { return console; } 

	/**
	 * Insert the method's description here.
	 * @see ViewPart#createPartControl
	 */
	public void createPartControl(Composite parent)  {
		//viewer = new TextViewer(parent, SWT.WRAP | SWT.V_SCROLL | SWT.H_SCROLL);
		viewer = new TextConsoleViewer(
					parent, console);
		GridData viewerData = new GridData(GridData.FILL_BOTH);
		viewer.getControl().setLayoutData(viewerData);
		//viewer.setDocument(document);		
		viewer.setEditable(false);
		
	}


	/**
	 * Set the text for the viewer
	 */
	public void appendOutputText(String text) 
	{
		console.getDocument().set(console.getDocument().get()+text);
	}

	private void showMessage(String message) {
		MessageDialog.openInformation(
			viewer.getControl().getShell(),
			"RML Console View",
			message);
	}

	/**
	 * Passing the focus request to the viewer's control.
	 */
	public void setFocus() {
		viewer.getControl().setFocus();
	}
}

